@@ -5,10 +5,13 @@
 #'
 #' @param model the multinomial model, from a \code{\link{multinom}}()-function call (see the \code{\link{nnet}} package)
 #' @param data the data with which the model was estimated
-#' @param xvari the name of the variable that should be varied (the x-axis variable in prediction plots)
-#' @param scenname if you want to hold a specific variable stable over all scenarios, you can name it here (optional).
-#' @param scenvalue determine at which value you want to fix the \code{scenname}.
-#' @param by define the steps of the \code{xvari}.
+#' @param x the name of the variable that should be varied (the x-axis variable in prediction plots)
+#' @param z if you want to hold a specific variable stable over all scenarios, you can name it here (optional).
+#' @param z_value determine at which value you want to fix the \code{z}.
+#' @param xvari former argument for \code{x} (deprecated).
+#' @param scenname former argument for \code{z} (deprecated).
+#' @param scenvalue former argument for \code{z_value} (deprecated).
+#' @param by define the steps of \code{x}.
 #' @param nsim numbers of simulations
 #' @param seed set a seed for replication purposes.
 #' @param probs a vector with two numbers, defining the significance levels. Default to 5\% significance level: \code{c(0.025, 0.975)}
@@ -28,7 +31,7 @@
 #' mod <- multinom(y ~ x1 + x2 + x3, data = dataset, Hess = TRUE)
 #'
 #' pred <- mnl_pred_ova(model = mod, data = dataset,
-#'                      xvari = "x1",
+#'                      x = "x1",
 #'                      nsim = 10)
 #'
 #'
@@ -39,14 +42,37 @@
 
 mnl_pred_ova <- function(model,
                          data,
-                         xvari,
+                         x,
                          by = NULL,
-                         scenname = NULL,
-                         scenvalue = NULL,
+                         z = NULL,
+                         z_value = NULL,
+                         xvari,
+                         scenname,
+                         scenvalue,
                          nsim = 1000,
                          seed = "random",
                          probs = c(0.025, 0.975)){
 
+  # Warnings for deprecated arguments
+  if (!missing(xvari)) {
+    warning("The argument 'xvari' is deprecated; please use 'x' instead.\n\n",
+            call. = FALSE)
+    x <- xvari
+  }
+
+  if (!missing(scenname)) {
+    warning("The argument 'scenname' is deprecated; please use 'z' instead.\n\n",
+            call. = FALSE)
+    z <- scenname
+  }
+
+  if (!missing(scenvalue)) {
+    warning("The argument 'scenvalue' is deprecated; please use 'z_value' instead.\n\n",
+            call. = FALSE)
+    z_value <- scenvalue
+  }
+
+
   # Errors:
   if (is.null(model) == TRUE) {
     stop("Please supply a model")
@@ -60,7 +86,7 @@ mnl_pred_ova <- function(model,
     stop("Please supply a data set")
   }
 
-  if (is.null(xvari) == TRUE | is.character(xvari) == FALSE) {
+  if (is.null(x) == TRUE | is.character(x) == FALSE) {
     stop("Please supply a character string of your x-variable of interest")
   }
 
@@ -71,17 +97,17 @@ mnl_pred_ova <- function(model,
   # Names of variables in model (without the "list" character in the vector)
   variables <- as.character(attr(model$terms, "variables"))[-1]
 
-  if(!(xvari %in% variables) == TRUE){
+  if(!(x %in% variables) == TRUE){
     stop("x-variable is not an independent variable in the model. There might be a typo.")
   }
 
   # Check if scenario is supplied correctly
-  if (is.null(scenname) == FALSE & is.character(scenname) == FALSE) {
+  if (is.null(z) == FALSE & is.character(z) == FALSE) {
     stop("Please supply a character string of your scenario of interest")
   }
 
-  if(is.null(scenname) == FALSE){
-    if (!(scenname %in% variables) == TRUE) {
+  if(is.null(z) == FALSE){
+    if (!(z %in% variables) == TRUE) {
       stop("The scenario variable is not an independent variable in the model. There might be a typo.")
     }
   }
@@ -113,13 +139,13 @@ mnl_pred_ova <- function(model,
 
   # Artificial variation of independent variable of interest (x)
   if (is.null(by) == TRUE) {
-    by <- abs(min(eval(parse(text = paste0("data$", xvari))), na.rm = TRUE) -
-      max(eval(parse(text = paste0("data$", xvari))), na.rm = TRUE))
+    by <- abs(min(eval(parse(text = paste0("data$", x))), na.rm = TRUE) -
+      max(eval(parse(text = paste0("data$", x))), na.rm = TRUE))
   }
 
-  variation <- seq(from = min(eval(parse(text = paste0("data$", xvari))),
+  variation <- seq(from = min(eval(parse(text = paste0("data$", x))),
                               na.rm = TRUE),
-                   to = max(eval(parse(text = paste0("data$", xvari))),
+                   to = max(eval(parse(text = paste0("data$", x))),
                             na.rm = TRUE),
                    by = by)
 
@@ -183,7 +209,7 @@ mnl_pred_ova <- function(model,
   ovacases[,,] <- X
 
   # Select the position of the variable which should vary:
-  varidim <- which(colnames(X) == xvari)
+  varidim <- which(colnames(X) == x)
 
 
   # Artificially alter the variable in each dimension according to
@@ -193,11 +219,11 @@ mnl_pred_ova <- function(model,
   }
 
   # Hold a second variable steady (if need be)
-  if(is.null(scenname) == FALSE) {
-    scendim <- which(colnames(X) == scenname)
+  if(is.null(z) == FALSE) {
+    scendim <- which(colnames(X) == z)
 
     for (i in 1:nseq) {
-      ovacases[, scendim, i] <- scenvalue
+      ovacases[, scendim, i] <- z_value
     }
   }
 
@@ -262,7 +288,7 @@ mnl_pred_ova <- function(model,
   # Multinomial link function:
 
   # 1. Part: Sum over cases
-  Sexp <- apply(ovaV, c(1, 2, 3), function(x) sum(exp(x)))
+  Sexp <- rowSums(exp(ovaV), dims = 3L)
 
   # Create P (array with predictions)
   P <- array(NA, c(nsim, J, nseq))
@@ -276,18 +302,22 @@ mnl_pred_ova <- function(model,
 
   for (l in 1:nseq) {
     for (m in 1:J) {
-      P[, m, l] <- apply(exp(ovaV[, , l, m])/Sexp[, , l], 2, mean)
+      P[, m, l] <- colMeans(exp(ovaV[, , l, m]) / Sexp[, , l])
+      if (sum(is.na(P[, m, l])) != 0) {
+        stop("Stop")
+      }
     }
 
     # Progress bar:
     setTxtProgressBar(pb_link, l)
   }
 
+
   output[["P"]] <- P
 
   # Aggregate the simulations
   # Create tibble for plot
-  # if (is.null(scenvalue) == TRUE) {
+  # if (is.null(z_value) == TRUE) {
   #   plotdat <- tibble::tibble(iv = rep(variation, J),
   #                             categories = rep(categories, each = length(variation)),
   #                             mean = NA,
@@ -296,13 +326,13 @@ mnl_pred_ova <- function(model,
   # } else {
   #   plotdat <- tibble::tibble(iv = rep(variation, J),
   #                             categories = rep(categories, each = length(variation)),
-  #                             scen = rep(scenvalue, each = length(categories)),
+  #                             scen = rep(z_value, each = length(categories)),
   #                             mean = NA,
   #                             lower = NA,
   #                             upper = NA)
   # }
 
-  if (is.null(scenvalue) == TRUE) {
+  if (is.null(z_value) == TRUE) {
     plotdat <- data.frame(iv = rep(variation, J),
                           categories = rep(categories, each = length(variation)),
                           mean = NA,
@@ -311,7 +341,7 @@ mnl_pred_ova <- function(model,
   } else {
     plotdat <- data.frame(iv = rep(variation, J),
                           categories = rep(categories, each = length(variation)),
-                          scen = rep(scenvalue, each = length(variation)),
+                          scen = rep(z_value, each = length(variation)),
                           mean = NA,
                           lower = NA,
                           upper = NA)
@@ -324,17 +354,17 @@ mnl_pred_ova <- function(model,
 
   for (i in 1:J) {
     end <- i*length(variation)
-    plotdat[c(start:end), "mean"] <- apply(P[, i,], 2, mean)
+    plotdat[c(start:end), "mean"] <- colMeans(P[, i,])
     plotdat[c(start:end), "lower"] <- apply(P[, i,], 2, quantile, probs = probs[1])
     plotdat[c(start:end), "upper"] <- apply(P[, i,], 2, quantile, probs = probs[2])
     start <- end+1
   }
 
   # Rename the variables in the plot data
-  if (is.null(scenname) == TRUE) {
-    colnames(plotdat)[1:2] <- c(xvari, dv)
+  if (is.null(z) == TRUE) {
+    colnames(plotdat)[1:2] <- c(x, dv)
   } else {
-    colnames(plotdat)[1:3] <- c(xvari, dv, scenname)
+    colnames(plotdat)[1:3] <- c(x, dv, z)
   }
 
 
